# References

(citation)=
## Citing Fastscapelib

If you want to use fastscapelib in a scientific publication, we would
appreciate a citation. We provide DOIs for specific versions via
Zenodo. Click on the badge below for more information on how to cite
the latest version of fastscapelib.

[![zenodo](https://zenodo.org/badge/133639708.svg)](https://zenodo.org/badge/latestdoi/133639708)

## Related Publications

Below is a list of publications that are referenced in this documentation. It
mostly corresponds to the articles that describe the algorithms implemented in
this library.

```{bibliography} references.bib
```
